@@ -387,6 +387,10 @@ pub struct RefAsBox;
 /// Types like `OsString` and `PathBuf` aren't guaranteed to be encoded as UTF-8, but they usually
 /// are anyway. Using this wrapper will archive them as if they were regular `String`s.
 ///
+/// Regular serializers don't support the custom error handling needed for this type by default. To
+/// use this wrapper, a custom serializer with an error type satisfying
+/// `<S as Fallible>::Error: From<AsStringError>` must be provided.
+///
 /// # Example
 ///
 /// ```
@@ -432,6 +436,10 @@ impl ::std::error::Error for AsStringError {}
 /// panic under any circumstances, it's recommended that you lock your values and then serialize
 /// them while locked.
 ///
+/// Regular serializers don't support the custom error handling needed for this type by default. To
+/// use this wrapper, a custom serializer with an error type satisfying
+/// `<S as Fallible>::Error: From<LockError>` must be provided.
+///
 /// # Example
 ///
 /// ```
@@ -562,6 +570,10 @@ pub struct CopyOptimize;
 /// The resulting archived time will be an [`ArchivedDuration`](crate::time::ArchivedDuration)
 /// relative to the UNIX epoch.
 ///
+/// Regular serializers don't support the custom error handling needed for this type by default. To
+/// use this wrapper, a custom serializer with an error type satisfying
+/// `<S as Fallible>::Error: From<UnixTimestampError>` must be provided.
+///
 /// # Example
 ///
 /// ```
@@ -591,3 +603,38 @@ impl fmt::Display for UnixTimestampError {
 
 #[cfg(feature = "std")]
 impl ::std::error::Error for UnixTimestampError {}
+
+/// A wrapper that provides an optimized bulk data array. This is primarily intended for large
+/// amounts of raw data, like bytes, floats, or integers.
+///
+/// This wrapper can be used with containers like `Vec`, but care must be taken to ensure that they
+/// contain copy-safe types. Copy-safe types must be trivially copyable (have the same archived and
+/// unarchived representations) and contain no padding bytes. In situations where copying
+/// uninitialized bytes the output is acceptable, this wrapper may be used with containers of types
+/// that contain padding bytes.
+///
+/// Unlike [`CopyOptimize`], this wrapper will also skip validation for its elements. If the
+/// elements of the container can have any invalid bit patterns (e.g. `char`, `bool`, complex
+/// containers, etc.), then using `Raw` in an insecure setting can lead to undefined behavior. Take
+/// great caution!
+///
+/// # Safety
+///
+/// Using this wrapper with containers containing non-copy-safe types or types that require
+/// validation may result in undefined behavior.
+///
+/// # Example
+///
+/// ```
+/// use rkyv::{Archive, with::Raw};
+///
+/// #[derive(Archive)]
+/// struct Example {
+///     #[with(Raw)]
+///     bytes: Vec<u8>,
+///     #[with(Raw)]
+///     vertices: Vec<[f32; 3]>,
+/// }
+/// ```
+#[derive(Debug)]
+pub struct Raw;
